==> kubernetes-model-1.0.36-sources.jar: io/fabric8/kubernetes/api/model/extensions/SubresourceReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class SubresourceReferenceBuilder extends SubresourceReferenceFluentImpl<SubresourceReferenceBuilder> implements VisitableBuilder<SubresourceReference,SubresourceReferenceBuilder>{

     SubresourceReferenceFluent<?> fluent;
public SubresourceReferenceBuilder(){
    this(new SubresourceReference());
}
public SubresourceReferenceBuilder( SubresourceReferenceFluent<?> fluent ){
    this(fluent, new SubresourceReference());
}
public SubresourceReferenceBuilder( SubresourceReferenceFluent<?> fluent , SubresourceReference instance ){
    this.fluent = fluent; fluent.withApiVersion(instance.getApiVersion()); fluent.withKind(instance.getKind()); fluent.withName(instance.getName()); fluent.withSubresource(instance.getSubresource()); 
}
public SubresourceReferenceBuilder( SubresourceReference instance ){
    this.fluent = this; this.withApiVersion(instance.getApiVersion()); this.withKind(instance.getKind()); this.withName(instance.getName()); this.withSubresource(instance.getSubresource()); 
}

public EditableSubresourceReference build(){
    EditableSubresourceReference buildable = new EditableSubresourceReference(fluent.getApiVersion(),fluent.getKind(),fluent.getName(),fluent.getSubresource());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
SubresourceReferenceBuilder that = (SubresourceReferenceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/extensions/SubresourceReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class SubresourceReferenceBuilder extends SubresourceReferenceFluentImpl<SubresourceReferenceBuilder> implements VisitableBuilder<SubresourceReference,SubresourceReferenceBuilder>{

     SubresourceReferenceFluent<?> fluent;
public SubresourceReferenceBuilder(){
    this(new SubresourceReference());
}
public SubresourceReferenceBuilder( SubresourceReferenceFluent<?> fluent ){
    this(fluent, new SubresourceReference());
}
public SubresourceReferenceBuilder( SubresourceReferenceFluent<?> fluent , SubresourceReference instance ){
    this.fluent = fluent; fluent.withApiVersion(instance.getApiVersion()); fluent.withKind(instance.getKind()); fluent.withName(instance.getName()); fluent.withSubresource(instance.getSubresource()); 
}
public SubresourceReferenceBuilder( SubresourceReference instance ){
    this.fluent = this; this.withApiVersion(instance.getApiVersion()); this.withKind(instance.getKind()); this.withName(instance.getName()); this.withSubresource(instance.getSubresource()); 
}

public SubresourceReference build(){
    SubresourceReference buildable = new SubresourceReference(fluent.getApiVersion(),fluent.getKind(),fluent.getName(),fluent.getSubresource());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
SubresourceReferenceBuilder that = (SubresourceReferenceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
